==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkChaosFluentImpl<A extends NetworkChaosFluent<A>> extends BaseFluent<A> implements NetworkChaosFluent<A>{
  public NetworkChaosFluentImpl() {
  }
  public NetworkChaosFluentImpl(NetworkChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private NetworkChaosSpecBuilder spec;
  private NetworkChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public NetworkChaosFluent.MetadataNested<A> withNewMetadata() {
    return new NetworkChaosFluentImpl.MetadataNestedImpl();
  }
  public NetworkChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new NetworkChaosFluentImpl.MetadataNestedImpl(item);
  }
  public NetworkChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public NetworkChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public NetworkChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public NetworkChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(NetworkChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new NetworkChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NetworkChaosFluent.SpecNested<A> withNewSpec() {
    return new NetworkChaosFluentImpl.SpecNestedImpl();
  }
  public NetworkChaosFluent.SpecNested<A> withNewSpecLike(NetworkChaosSpec item) {
    return new NetworkChaosFluentImpl.SpecNestedImpl(item);
  }
  public NetworkChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NetworkChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new NetworkChaosSpecBuilder().build());
  }
  public NetworkChaosFluent.SpecNested<A> editOrNewSpecLike(NetworkChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public NetworkChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(NetworkChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new NetworkChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public NetworkChaosFluent.StatusNested<A> withNewStatus() {
    return new NetworkChaosFluentImpl.StatusNestedImpl();
  }
  public NetworkChaosFluent.StatusNested<A> withNewStatusLike(NetworkChaosStatus item) {
    return new NetworkChaosFluentImpl.StatusNestedImpl(item);
  }
  public NetworkChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public NetworkChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new NetworkChaosStatusBuilder().build());
  }
  public NetworkChaosFluent.StatusNested<A> editOrNewStatusLike(NetworkChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkChaosFluentImpl that = (NetworkChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<NetworkChaosFluent.MetadataNested<N>> implements NetworkChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends NetworkChaosSpecFluentImpl<NetworkChaosFluent.SpecNested<N>> implements NetworkChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(NetworkChaosSpec item) {
      this.builder = new NetworkChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new NetworkChaosSpecBuilder(this);
    }
    NetworkChaosSpecBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends NetworkChaosStatusFluentImpl<NetworkChaosFluent.StatusNested<N>> implements NetworkChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(NetworkChaosStatus item) {
      this.builder = new NetworkChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new NetworkChaosStatusBuilder(this);
    }
    NetworkChaosStatusBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkChaosFluentImpl<A extends NetworkChaosFluent<A>> extends BaseFluent<A> implements NetworkChaosFluent<A>{
  public NetworkChaosFluentImpl() {
  }
  public NetworkChaosFluentImpl(NetworkChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private NetworkChaosSpecBuilder spec;
  private NetworkChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public NetworkChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new NetworkChaosFluentImpl.MetadataNestedImpl();
  }
  public NetworkChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new NetworkChaosFluentImpl.MetadataNestedImpl(item);
  }
  public NetworkChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public NetworkChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public NetworkChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public NetworkChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(NetworkChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new NetworkChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public NetworkChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new NetworkChaosFluentImpl.SpecNestedImpl();
  }
  public NetworkChaosFluentImpl.SpecNested<A> withNewSpecLike(NetworkChaosSpec item) {
    return new NetworkChaosFluentImpl.SpecNestedImpl(item);
  }
  public NetworkChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public NetworkChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new NetworkChaosSpecBuilder().build());
  }
  public NetworkChaosFluentImpl.SpecNested<A> editOrNewSpecLike(NetworkChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public NetworkChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public NetworkChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(NetworkChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new NetworkChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public NetworkChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new NetworkChaosFluentImpl.StatusNestedImpl();
  }
  public NetworkChaosFluentImpl.StatusNested<A> withNewStatusLike(NetworkChaosStatus item) {
    return new NetworkChaosFluentImpl.StatusNestedImpl(item);
  }
  public NetworkChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public NetworkChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new NetworkChaosStatusBuilder().build());
  }
  public NetworkChaosFluentImpl.StatusNested<A> editOrNewStatusLike(NetworkChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkChaosFluentImpl that = (NetworkChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<NetworkChaosFluentImpl.MetadataNested<N>> implements NetworkChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends NetworkChaosSpecFluentImpl<NetworkChaosFluentImpl.SpecNested<N>> implements NetworkChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(NetworkChaosSpec item) {
      this.builder = new NetworkChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new NetworkChaosSpecBuilder(this);
    }
    NetworkChaosSpecBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends NetworkChaosStatusFluentImpl<NetworkChaosFluentImpl.StatusNested<N>> implements NetworkChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(NetworkChaosStatus item) {
      this.builder = new NetworkChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new NetworkChaosStatusBuilder(this);
    }
    NetworkChaosStatusBuilder builder;
    public N and() {
      return (N) NetworkChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
